import { ViewStyle, NativeMethods, LayoutRectangle, Animated, ScrollView } from 'react-native';
import React$1, { PropsWithChildren } from 'react';
import { NativeMethods as NativeMethods$1 } from 'react-native/types';
import { Emitter } from 'mitt';

interface Step {
    name: string;
    order: number;
    visible: boolean;
    wrapperRef: React.RefObject<NativeMethods>;
    measure: () => Promise<LayoutRectangle>;
    text: string;
}
interface ValueXY {
    x: number;
    y: number;
}
type SvgMaskPathFunction = (args: {
    size: Animated.ValueXY;
    position: Animated.ValueXY;
    canvasSize: ValueXY;
    step: Step;
}) => string;
type Labels = Partial<Record<"skip" | "previous" | "next" | "finish", string>>;
interface StepNumberProps {
    currentStepNumber: number;
    isFirstStep: boolean;
    isLastStep: boolean;
    currentStep: Step;
}
interface TooltipProps {
    isFirstStep: boolean;
    isLastStep: boolean;
    handleNext: () => void;
    handleNth: (n: number) => void;
    handlePrev: () => void;
    handleStop: () => void;
    currentStep: Step;
    labels: Labels;
}
interface CopilotOptions {
    easing?: ((value: number) => number) | undefined;
    overlay?: "svg" | "view";
    animationDuration?: number;
    tooltipComponent?: React.ComponentType<any>;
    tooltipStyle?: ViewStyle;
    stepNumberComponent?: React.ComponentType<any>;
    animated?: boolean;
    labels?: Labels;
    androidStatusBarVisible?: boolean;
    svgMaskPath?: SvgMaskPathFunction;
    verticalOffset?: number;
    arrowColor?: string;
    stopOnOutsideClick?: boolean;
    backdropColor?: string;
}

type PropsWithCopilot<P> = P & {
    copilot: {
        ref?: React$1.RefObject<NativeMethods$1>;
        onLayout?: () => void;
    };
};
declare function walkthroughable<P = any>(WrappedComponent: React$1.ComponentType<P>): React$1.FunctionComponent<PropsWithCopilot<P>>;

interface Props {
    name: string;
    order: number;
    text: string;
    children: React$1.ReactElement<any>;
    active?: boolean;
}
declare const CopilotStep: ({ name, order, text, children, active, }: Props) => React$1.ReactElement<any, string | React$1.JSXElementConstructor<any>>;

type Events = {
    start: undefined;
    stop: undefined;
    stepChange: Step | undefined;
};
interface CopilotContextType {
    registerStep: (step: Step) => void;
    unregisterStep: (stepName: string) => void;
    getCurrentStep: () => Step | undefined;
    start: (fromStep?: string, suppliedScrollView?: ScrollView | null) => Promise<void>;
    stop: () => Promise<void>;
    goToNext: () => Promise<void>;
    goToNth: (n: number) => Promise<void>;
    goToPrev: () => Promise<void>;
    visible: boolean;
    copilotEvents: Emitter<Events>;
}
declare const CopilotProvider: ({ verticalOffset, children, ...rest }: PropsWithChildren<CopilotOptions>) => JSX.Element;
declare const useCopilot: () => CopilotContextType;

declare const DefaultUI: {
    StepNumber: ({ currentStepNumber }: StepNumberProps) => JSX.Element;
    Tooltip: ({ isFirstStep, isLastStep, handleNext, handlePrev, handleStop, currentStep, labels, }: TooltipProps) => JSX.Element;
};

export { CopilotOptions as CopilotProps, CopilotProvider, CopilotStep, DefaultUI, StepNumberProps, TooltipProps, useCopilot, walkthroughable };
